@@ -1,18 +1,22 @@
-#!/usr/bin/env python3
 """
-Example of program which uses [options] shortcut in pattern.
+低代码构建工具.
 
 Usage:
-  lesscodeTool (new -d dir [-p project]|sqlacodegen -u url [-t table][-f file])
+  lesscodeTool (new -d dir [-p project]|sqlacodegen -u url [-s schemas][-t tables][-f file]|subcommand -c command)
+
 Options:
-  -h, --help                查看帮助
+  -h, --help               查看帮助
   -v, --version            展示版本号
   -d, --dir dir            项目目录
   -u, --url url            数据库连接
   -f, --file file          表结构类输出文件
   -p, --project project    项目模板名
-  -t, --table table        表名
+  -t, --tables tables      表名，用英文逗号连接多个表
+  -s, --schemas schemas    库名，用英文逗号连接多个库
+  -c, --command command    执行系统命令
 """
+import os
+
 from docopt import docopt
 
 from pkg.tool.new import create_lesscode_project
@@ -24,6 +28,7 @@ def main():
     arguments = docopt(__doc__, version=__version__)
     new_command_flag = arguments.get("new")
     sqlacodegen_command_flag = arguments.get("sqlacodegen")
+    subcommand_flag = arguments.get("subcommand")
     if new_command_flag:
         project = arguments.get("--project")
         project_dir = arguments.get("--dir")
@@ -31,11 +36,21 @@ def main():
             project = "lesscode-py"
         if project == "lesscode-py":
             create_lesscode_project(project_dir)
-    if sqlacodegen_command_flag:
+    elif sqlacodegen_command_flag:
         url = arguments.get("--url")
         file = arguments.get("--file")
-        table = arguments.get("--table")
-        sqlacodegen(url, table, file)
+        schema = arguments.get("--schemas")
+        table = arguments.get("--tables")
+        schemas = None
+        tables = None
+        if schema is not None:
+            schemas = schema.split(",")
+        if table is not None:
+            tables = table.split(",")
+        sqlacodegen(url, schemas, tables, file)
+    elif subcommand_flag:
+        command = arguments.get("--command")
+        os.system(command)
 
 
 if __name__ == '__main__':
